#version 330 core

uniform sampler2D textureMap;

uniform float diffusePower;
uniform float specularPower;
uniform float ambientPower;
uniform float specularReflectionExponent;

uniform float transparency;

in vec2 uv;

in vec3 normal_eye;
in vec3 viewDirection_eye;
in vec3 lightDirection_eye;

out vec4 color;

void main(void)
{

	vec3 L = lightDirection_eye;
	vec3 N = normal_eye;
	vec3 V = viewDirection_eye;

	vec4 materialDiffuseColor = texture(textureMap, uv);
	vec4 materialAmbientColor = ambientPower * materialDiffuseColor;
	vec4 materialSpecularColor = vec4(0.3);

	float distance = length(L);
	L = L / distance; // = normalize(L)
	distance = distance * distance;

	float intensityDiffuse = clamp(dot(N,L), 0, 1);
	//vec4 diffuseColor = intensityDiffuse * materialDiffuseColor * diffusePower / distance;
	vec4 diffuseColor = intensityDiffuse * materialDiffuseColor * diffusePower;

	vec3 H = normalize(L + V); // half vector

	float intensitySpecular = clamp(dot(N, H), 0, 1);
	intensitySpecular = pow(intensitySpecular, specularReflectionExponent);
	//vec4 specularColor = intensitySpecular * materialSpecularColor * specularPower / distance;
	vec4 specularColor = intensitySpecular * materialSpecularColor * specularPower;

	vec4 ambientColor = materialAmbientColor;
	color = vec4((ambientColor + diffuseColor + specularColor).xyz, transparency);
	
}
